deepBlink — deepblink 0.0.1 documentation

# deepBlink

Threshold independent detection and localization of diffraction-limited spots.

## Overview

In biomedical microscopy data, a common task involves the detection of diffraction-limited spots that visualize single proteins, domains, mRNAs, and many more. These spots were traditionally detected with mathematical operators such as Laplacian of Gaussian. These operators, however, rely on human input ranging from image-intensity thresholds, approximative spot sizes, etc. This process is tedious and not always reliable. DeepBlink relies on neural networks to automatically find spots without the need for human intervention. DeepBlink is available as a ready-to-use command-line interface.

Example images will follow shortly.

## Installation

    pip install deepblink

You can also install the in-development version with:

    pip install git+ssh://git@github.com/bbquercus/deepblink/bbquercus/deepblink.git@master

## Documentation

https://deepblink.readthedocs.io/

## Development

To run the all tests run:

    tox

Note, to combine the coverage data from all the tox environments run:

Windows |
    set PYTEST_ADDOPTS=--cov-append
    tox
Other |
    PYTEST_ADDOPTS=--cov-append tox